@@ -2,4 +2,4 @@
 
 
 def runFlake8(package_name):
-    print('Running Flake8...')
\ No newline at end of file
+    print('Running Flake8 for %s...' % package_name)
