@@ -1,7 +1,9 @@
 '''Module for PyTest functionality.'''
 
-import subprocess
-import tempfile
+from __future__ import absolute_import
+
+import os
+from ._functions import executeShell
 
     
 def runPytest(package_name):
@@ -10,27 +12,27 @@ def runPytest(package_name):
     cmd = ['python',
            '-m',
            'pytest',
+           '-v',
            '--cov=%s' % package_name,
            '--cov-report=term',
            '--cov-report=xml',
-           '--cov-branch',
-           '--cov-config=%s/tests/.coveragerc' % package_name,
-           '%s/tests/' % package_name
-           ]
+           '--cov-branch']
+    if os.path.exists('./tests'):
+        test_dir = 'tests'
+    elif os.path.exists('%s/tests' % package_name):
+        test_dir = '%s/tests' % package_name
+    
+    coveragerc_path = '%s/.coveragerc' % test_dir
+    if os.path.exists(coveragerc_path):
+        cmd += ['--cov-config=%s' % coveragerc_path]
+    
+    cmd += [test_dir]
     print(' '.join(cmd))
-    with tempfile.TemporaryFile() as tempf:
-        proc = subprocess.Popen(cmd,
-                                stdout=tempf)
-        proc.wait()
-        tempf.seek(0)
-        output = str(tempf.read().decode())
-        
-    print(output)
-    with open('coverage.txt', 'w') as f:
-        f.writelines(output)
+    
+    executeShell(cmd, save_output_as='coverage.txt')
         
 
-class CoverageReport():
+class CoverageReport(object):
     def __init__(self, txt=None, xml=None):
         if txt is None:
             txt = 'coverage.txt'
@@ -54,8 +56,8 @@ class CoverageReport():
         for line in lines:
             if '-- coverage:' in line:
                 in_coverage = True
-            if line[:5] == 'TOTAL':
+            if in_coverage and line[:5] == 'TOTAL':
                 coverage = line.split()[-1]
                 break
         
-        return coverage
\ No newline at end of file
+        return coverage
